==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/datatransfer/DataFlavor.hpp <==
#ifndef _COM_SUN_STAR_DATATRANSFER_DATAFLAVOR_HPP_
#define _COM_SUN_STAR_DATATRANSFER_DATAFLAVOR_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_DATATRANSFER_DATAFLAVOR_HDL_
#include "com/sun/star/datatransfer/DataFlavor.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace datatransfer {

inline DataFlavor::DataFlavor() SAL_THROW( () )
    : MimeType()
    , HumanPresentableName()
    , DataType()
{
}

inline DataFlavor::DataFlavor(const ::rtl::OUString& MimeType_, const ::rtl::OUString& HumanPresentableName_, const ::com::sun::star::uno::Type& DataType_) SAL_THROW( () )
    : MimeType(MimeType_)
    , HumanPresentableName(HumanPresentableName_)
    , DataType(DataType_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::datatransfer::DataFlavor const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.datatransfer.DataFlavor");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_DATATRANSFER_DATAFLAVOR_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/datatransfer/DataFlavor.hpp <==
#ifndef _COM_SUN_STAR_DATATRANSFER_DATAFLAVOR_HPP_
#define _COM_SUN_STAR_DATATRANSFER_DATAFLAVOR_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_DATATRANSFER_DATAFLAVOR_HDL_
#include "com/sun/star/datatransfer/DataFlavor.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace datatransfer {

inline DataFlavor::DataFlavor() SAL_THROW( () )
    : MimeType()
    , HumanPresentableName()
    , DataType()
{
}

inline DataFlavor::DataFlavor(const ::rtl::OUString& MimeType_, const ::rtl::OUString& HumanPresentableName_, const ::com::sun::star::uno::Type& DataType_) SAL_THROW( () )
    : MimeType(MimeType_)
    , HumanPresentableName(HumanPresentableName_)
    , DataType(DataType_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace datatransfer {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::datatransfer::DataFlavor const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.datatransfer.DataFlavor");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::datatransfer::DataFlavor const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::datatransfer::DataFlavor >::get();
}

#endif // _COM_SUN_STAR_DATATRANSFER_DATAFLAVOR_HPP_
